REST API — OppiaMobile-Server 0.1.10 documentation

### Navigation

- index
- modules |
- previous |
- OppiaMobile-Server 0.1.10 documentation »

# REST API

class `api.resources.` `UserResource`(api_name=None)

  For user login

  Usage: POST request to `http://localhost/api/v1/user/`

  Required arguments:

  - `username`
  - `password`

  Returns (if authorized):

  Object with `first_name`, `last_name`, `api_key`, `last_login`, `username`, `points` and `badges`

  If unauthorized returns an HTTP 401 response

class `api.resources.` `RegisterResource`(api_name=None)

  For user registration

class `api.resources.` `TrackerResource`(api_name=None)

  Submitting a Tracker

class `api.resources.` `CourseResource`(api_name=None)

class `api.resources.` `CourseTagResource`(api_name=None)

class `api.resources.` `ScheduleResource`(api_name=None)

class `api.resources.` `TagResource`(api_name=None)

class `api.resources.` `ActivityScheduleResource`(api_name=None)

class `api.resources.` `PointsResource`(api_name=None)

class `api.resources.` `BadgesResource`(api_name=None)

class `api.resources.` `AwardsResource`(api_name=None)

class `api.resources.` `ScorecardResource`(api_name=None)

class `quiz.api.resources.` `QuizResource`(api_name=None)

class `quiz.api.resources.` `QuizQuestionResource`(api_name=None)

class `quiz.api.resources.` `QuestionResource`(api_name=None)

class `quiz.api.resources.` `QuestionPropsResource`(api_name=None)

class `quiz.api.resources.` `ResponseResource`(api_name=None)

class `quiz.api.resources.` `ResponsePropsResource`(api_name=None)

class `quiz.api.resources.` `QuizPropsResource`(api_name=None)

class `quiz.api.resources.` `QuizAttemptResponseResource`(api_name=None)

class `quiz.api.resources.` `QuizAttemptResource`(api_name=None)

### Navigation

- index
- modules |
- previous |
- OppiaMobile-Server 0.1.10 documentation »